const {connectUserToRoom, roomExists, disconnectUser, getUserRoom, getRoomUsers} = require("../controller/room");

module.exports = (socket) => {
    let currentRoomId = null;
    let currentUser = null;

    socket.on("disconnect", () => {
        const roomId = getUserRoom(socket.id);
        if (roomId) socket.to(roomId).emit("user-disconnected", socket.id);

        disconnectUser(socket.id);
    });

    socket.on("join-room", ({roomId, name}) => {
        if (currentRoomId) return socket.emit("already-in-room", currentRoomId);

        if (roomExists(roomId.toString())) {
            currentUser = {id: socket.id, name: name.toString()};
            connectUserToRoom(roomId, currentUser);
            socket.join(roomId);
            socket.to(roomId).emit("user-connected", currentUser);
            socket.emit("room-joined", roomId);
            currentRoomId = roomId;
        } else {
            socket.emit("room-not-found", roomId.toString());
        }
    });

    socket.on("create-room", ({name}) => {
        if (!name) return socket.emit("room-name-required");
        const roomId = Math.random().toString(36).substring(7);
        currentUser = {id: socket.id, name: name?.toString()};
        connectUserToRoom(roomId, currentUser);
        socket.join(roomId);
        socket.emit("room-created", roomId);
        currentRoomId = roomId;
    });

    socket.on("send-message", (messageData) => {
        const roomId = getUserRoom(socket.id);
        if (roomId) {
            socket.to(roomId).emit("chat-message", messageData);
        }
    });

    socket.on("get-user-info", () => {
        if (currentUser) {
            socket.emit("user-info", currentUser);
        }
    });

    socket.on("get-room-users", () => {
        const roomId = getUserRoom(socket.id);
        if (roomId) {
            const users = getRoomUsers(roomId);
            socket.emit("room-users", users);
        }
    });
}